# WARNING: This package is synchronized with Fedora!

# pkgconf acts as pkgconfig by default for Mageia 7 and newer
%bcond_without pkgconfig_compat

%if %{with pkgconfig_compat}
%global pkgconfig_ver 0.29.2
# For obsoleting pkgconfig, bump the rel to a number higher than latest build
%global pkgconfig_verrel %{pkgconfig_ver}-2
%endif

# Search path for pc files for pkgconf
%global pkgconf_libdirs %{_libdir}/pkgconfig:%{_datadir}/pkgconfig

%global somajor 3
%global libname %mklibname %{name} %{somajor}
%global devname %mklibname %{name} -d

Name:           pkgconf
Version:        1.8.0
Release:        %mkrel 3
Summary:        Package compiler and linker metadata toolkit
Group:          Development/Tools
License:        ISC
URL:            http://pkgconf.org/
Source0:        https://distfiles.dereferenced.org/%{name}/%{name}-%{version}.tar.xz

# Simple wrapper script to offer platform versions of pkgconfig
Source1:        platform-pkg-config.in

Patch0:         81cc9b3e6dafcdd02579bcccec6ac47d91e5d023.patch

BuildRequires:  gcc
BuildRequires:  make

# For regenerating autotools scripts
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

# For unit tests
BuildRequires:  kyua
BuildRequires:  atf-tests

# pkgconf uses libpkgconf internally
Requires:       %{libname}%{?_isa} = %{version}-%{release}

# This is defined within pkgconf code as a virtual pc (just like in pkgconfig)
Provides:       pkgconfig(pkgconf) = %{version}

%description
pkgconf is a program which helps to configure compiler and linker flags
for development frameworks. It is similar to pkg-config from freedesktop.org
and handles .pc files in a similar manner as pkg-config.

%package -n %{libname}
Summary:        Backend library for %{name}
Group:          System/Libraries

%description -n %{libname}
This package provides libraries for applications to use the functionality
of %{name}.

%package -n %{devname}
Summary:        Development files for lib%{name}
Group:          Development/C
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package provides files necessary for developing applications
to use functionality provided by %{name}.

%if %{with pkgconfig_compat}
%package m4
Summary:        m4 macros for pkgconf
Group:          Development/Other
License:        GPLv2+ with exceptions
BuildArch:      noarch
# Ensure that it Conflicts and Obsoletes pkgconfig since it contains content formerly from it
Conflicts:      pkgconfig < %{pkgconfig_verrel}

%description m4
This package includes m4 macros used to support PKG_CHECK_MODULES
when using pkgconf with autotools.

%package pkg-config
Summary:        %{name} shim to provide /usr/bin/pkg-config
Group:          Development/Tools
# Ensure that it Conflicts with pkgconfig and is considered "better"
Conflicts:      pkgconfig < %{pkgconfig_verrel}
Obsoletes:      pkgconfig < %{pkgconfig_verrel}
Provides:       pkgconfig = %{pkgconfig_verrel}
Provides:       pkgconfig%{?_isa} = %{pkgconfig_verrel}
# This is in the original pkgconfig package, set to match output from pkgconf
Provides:       pkgconfig(pkg-config) = %{version}
# Generic pkg-config Provides for those who might use alternate package name
Provides:       pkg-config = %{pkgconfig_verrel}
Provides:       pkg-config%{?_isa} = %{pkgconfig_verrel}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-m4 = %{version}-%{release}

%description pkg-config
This package provides the shim links for pkgconf to be automatically
used in place of pkgconfig. This ensures that pkgconf is used as
the system provider of pkg-config.

%endif


%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --disable-static \
           --with-pkg-config-dir=%{pkgconf_libdirs} \
           --with-system-includedir=%{_includedir} \
           --with-system-libdir=%{_libdir}

%make_build


%check
make check


%install
%make_install

find %{buildroot} -name '*.la' -print -delete

mkdir -p %{buildroot}%{_sysconfdir}/pkgconfig/personality.d
mkdir -p %{buildroot}%{_datadir}/pkgconfig/personality.d

# pkgconf rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}/

cat > %{buildroot}%{_rpmmacrodir}/macros.pkgconf <<EOM
%%pkgconfig_personalitydir %{_datadir}/pkgconfig/personality.d
EOM

%if %{with pkgconfig_compat}
install -pm 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{_target_platform}-pkg-config

sed -e "s|@TARGET_PLATFORM@|%{_target_platform}|" \
    -e "s|@PKGCONF_LIBDIRS_LOCAL@|/usr/local/%{_lib}/pkgconfig:/usr/local/share/pkgconfig:%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_SYSLIBDIR_LOCAL@|/usr/local/%{_lib}:%{_libdir}|" \
    -e "s|@PKGCONF_SYSINCDIR_LOCAL@|/usr/local/include:%{_includedir}|" \
    -e "s|@PKGCONF_LIBDIRS@|%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_SYSLIBDIR@|%{_libdir}|" \
    -e "s|@PKGCONF_SYSINCDIR@|%{_includedir}|" \
    -i %{buildroot}%{_bindir}/%{_target_platform}-pkg-config


ln -sr %{buildroot}%{_bindir}/%{_target_platform}-pkg-config %{buildroot}%{_bindir}/pkg-config

# Link pkg-config(1) to pkgconf(1)
echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/pkg-config.1

mkdir -p %{buildroot}%{_libdir}/pkgconfig
mkdir -p %{buildroot}%{_datadir}/pkgconfig
%endif

# If we're not providing pkgconfig override & compat
# we should not provide the pkgconfig m4 macros
%if ! %{with pkgconfig_compat}
rm -rf %{buildroot}%{_datadir}/aclocal
rm -rf %{buildroot}%{_mandir}/man7
%endif

%files
%license COPYING
%doc README.md AUTHORS NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_mandir}/man5/%{name}-personality.5*
%{_mandir}/man5/pc.5*
%{_rpmmacrodir}/macros.pkgconf
%dir %{_sysconfdir}/pkgconfig
%dir %{_sysconfdir}/pkgconfig/personality.d
%dir %{_datadir}/pkgconfig/personality.d

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}*.so.%{somajor}
%{_libdir}/lib%{name}*.so.%{somajor}.*

%files -n %{devname}
%{_libdir}/lib%{name}*.so
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/lib%{name}.pc

%if %{with pkgconfig_compat}
%files m4
%{_datadir}/aclocal/pkg.m4
%{_mandir}/man7/pkg.m4.7*

%files pkg-config
%{_bindir}/pkg-config
%{_bindir}/%{_target_platform}-pkg-config
%{_mandir}/man1/pkg-config.1*
%dir %{_libdir}/pkgconfig
%dir %{_datadir}/pkgconfig
%endif



%changelog
* Wed Mar 01 2023 ns80 <ns80> 1.8.0-3.mga9
+ Revision: 1946158
- add an upstream patch for CVE-2023-24056 (mga#31536)

* Sat Mar 19 2022 umeabot <umeabot> 1.8.0-2.mga9
+ Revision: 1799574
- Mageia 9 Mass Rebuild

* Fri Aug 06 2021 luigiwalser <luigiwalser> 1.8.0-1.mga9
+ Revision: 1739835
- 1.8.0

* Sun Apr 25 2021 wally <wally> 1.7.4-1.mga9
+ Revision: 1719410
- new version 1.7.4

* Sat Jan 09 2021 daviddavid <daviddavid> 1.7.3-2.mga8
+ Revision: 1669938
- rebuild for new kyua a replacement for kyua-cli

* Mon Aug 10 2020 ngompa <ngompa> 1.7.3-1.mga8
+ Revision: 1612521
- Update to 1.7.3
- Sync platform-pkg-config improvements from Fedora

* Sat Feb 15 2020 umeabot <umeabot> 1.6.3-2.mga8
+ Revision: 1528161
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Aug 12 2019 ngompa <ngompa> 1.6.3-1.mga8
+ Revision: 1428870
- Update to 1.6.3

* Wed May 01 2019 ngompa <ngompa> 1.6.1-1.mga7
+ Revision: 1396060
- Update to 1.6.1
- Add personality.d directories for cross-targets
- Add pkgconf rpm macros for pkgconf directories
- Simplify platform-pkg-config wrapper to work with POSIX sh

* Sat Jan 05 2019 ngompa <ngompa> 1.5.4-1.mga7
+ Revision: 1349897
- Rebase to 1.5.4

* Sun Sep 23 2018 umeabot <umeabot> 1.4.2-4.mga7
+ Revision: 1300295
- Mageia 7 Mass Rebuild

* Tue Jun 12 2018 wally <wally> 1.4.2-3.mga7
+ Revision: 1236603
- rebuild for aarch64

* Thu May 31 2018 tv <tv> 1.4.2-2.mga7
+ Revision: 1233319
- fix upgrade: only one pkg must obsolete pkgconfig

* Sat May 26 2018 ngompa <ngompa> 1.4.2-1.mga7
+ Revision: 1232336
- Update to 1.4.2
- Enable pkgconfig compatibility to replace legacy pkgconfig

* Mon Feb 19 2018 ngompa <ngompa> 1.4.1-1.mga7
+ Revision: 1203197
- Update to 1.4.1

* Sun Jan 07 2018 ngompa <ngompa> 1.4.0-1.mga7
+ Revision: 1191244
- Update to v1.4.0
- Add simple wrapper to support platform-specific pkg-config paths (rhbz#1513810)

* Sun Dec 03 2017 ngompa <ngompa> 1.3.10-3.mga7
+ Revision: 1180922
- Rebuild again for ARM

* Sun Dec 03 2017 ngompa <ngompa> 1.3.10-2.mga7
+ Revision: 1180913
- No change release bump to build for ARM

* Sun Nov 26 2017 ngompa <ngompa> 1.3.10-1.mga7
+ Revision: 1179971
- Update to v1.3.10
- Adapt for Mageia
- imported package pkgconf


* Wed Sep 20 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.9-1
- Update to 1.3.9

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 17 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.8-1
- Update to 1.3.8

* Sun May 28 2017 Neal Gompa <ngompa13@gmail.com> - 1.3.7-1
- Update to 1.3.7

* Wed May 10 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.6-1
- Update to 1.3.6

* Tue Apr 04 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.5-1
- Update to 1.3.5

* Thu Mar 30 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.4-1
- Update to 1.3.4

* Mon Mar 27 2017 Neal Gompa <ngompa13@gmail.com> - 1.3.3-1
- Update to 1.3.3

* Fri Mar 24 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.3.2-1
- Update to 1.3.2

* Sat Feb 25 2017 Neal Gompa <ngompa13@gmail.com> - 1.3.0-1
- Update to 1.3.0

* Tue Feb 07 2017 Neal Gompa <ngompa13@gmail.com> - 1.2.2-2
- Backport patch from upstream to remove extraneous whitespace (#1419685)

* Fri Feb 03 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.2.2-1
- Update to 1.2.2

* Thu Feb 02 2017 Neal Gompa <ngompa13@gmail.com> - 1.2.1-3
- Fix Obsoletes and Conflicts to prevent self-conflicts

* Thu Feb 02 2017 Neal Gompa <ngompa13@gmail.com> - 1.2.1-2
- Adjust Obsoletes and Conflicts to use inclusive range

* Tue Jan 24 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.2.1-1
- Update to 1.2.1

* Sat Jan 21 2017 Neal Gompa <ngompa13@gmail.com> - 1.2.0-1
- Upgrade to 1.2.0
- Enable pkgconf-pkg-config and pkgconf-m4 for F26+

* Sat Jan 14 2017 Neal Gompa <ngompa13@gmail.com> - 1.1.1-3
- Add missing pkgconfig() Provides for virtual .pc files defined in pkgconf

* Fri Jan 13 2017 Neal Gompa <ngompa13@gmail.com> - 1.1.1-2
- Add missing Epoch to pkgconfig Provides/Conflicts for pkgconf-pkg-config
- Add copy of pkgconf.1 as pkg-config.1 in pkgconf-pkg-config

* Sat Jan 07 2017 Neal Gompa <ngompa13@gmail.com> - 1.1.1-1
- Upgrade to 1.1.1
- Add missing directories to pkgconf-pkg-config

* Sun Jan 01 2017 Neal Gompa <ngompa13@gmail.com> - 1.1.0-3
- Fix up spec per package review (#1409332)

* Sat Dec 31 2016 Neal Gompa <ngompa13@gmail.com> - 1.1.0-2
- Rework package to not generate conflict with pkgconfig
- Disable pkgconf-m4 and pkgconf-pkg-config by default

* Sat Dec 31 2016 Neal Gompa <ngompa13@gmail.com> - 1.1.0-1
- Upgrade to 1.1.0
- Enable libpkgconf libraries now that they are ABI+API stable

* Tue Oct 25 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.2-1
- Upgrade to 1.0.2

* Fri Aug 26 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.1-2
- Add subpackage for providing pkg-config shim
- Enable tests

* Thu Aug 25 2016 Neal Gompa <ngompa13@gmail.com> - 1.0.1-1
- Upgrade to 1.0.1

* Wed Aug 24 2016 Neal Gompa <ngompa13@gmail.com> - 1-1
- Initial packaging
